@@ -29,6 +29,10 @@ test_that("General tests", {
   ##check verbose
   expect_silent(read_xyData(file = system.file("extdata/ExampleSpectrum.CNF", package = "rxylib"), verbose =  FALSE))
 
+  ##check list
+  l <- c(system.file("extdata/ExampleSpectrum.CNF", package = "rxylib"), system.file("extdata/ExampleSpectrum.CNF", package = "rxylib"))
+  expect_type(read_xyData(file = l, verbose =  TRUE), "list")
+
   ##check plot warning (and import of spectrum)
   expect_warning(plot(read_xyData(file = system.file("extdata/TLSpectrum.xsyg", package = "rxylib"), verbose =  FALSE)))
 
@@ -138,7 +142,7 @@ test_that("Check all formats", {
     expect_type(read_xyData(file = "http://www.cristal.org/DU-SDPD/semaine-2/na5+nac.udf"), type = "list")
 
     ##DBWS data
-    #expect_type(read_xyData("http://mysite.du.edu/~balzar/lebailbr.dbw"), type = "list")
+    expect_type(read_xyData("http://mysite.du.edu/~balzar/lebailbr.dbw"), type = "list")
 
     ##Rigaku (dat)
     expect_type(read_xyData("https://raw.githubusercontent.com/R-Lum/rxylib/master/tests/testdata/ExampleRigaku.dat"), type = "list")
